
#include "resource_obj.h"
#include "substring.h"
#include "multi_type.h"
#include "debug.h"


ResourceOBJ::ResourceOBJ(const std::string& imageName, float scaling)
    : Resource(&ResourceOBJ::type)
{
  Resources::StorePointer* ptr = this->acquireResource(imageName + ',' + MultiType(scaling).getString());

  if (ptr)
  {
    PRINTF(5)("FOUND OBJ: %s\n", imageName.c_str());
    this->acquireData(static_cast<ResourceOBJ::OBJResourcePointer*>(ptr)->ptr());
  }
  else
  {
    PRINTF(5)("NOT FOUND OBJ: %s\n", imageName.c_str());
    std::string fileName = this->Resource::locateFile(imageName);
    this->acquireData(OBJModel(fileName, scaling).dataPointer());
    this->Resource::addResource(new ResourceOBJ::OBJResourcePointer(imageName + ',' + MultiType(scaling).getString(), Resources::KeepLevel(0), this->StaticModel::dataPointer()));
  }
}

ResourceOBJ ResourceOBJ::createFromString(const std::string& loadString)
{
  SubString loadValues(loadString, ',');
  std::string imageName;
  float scaling = 1.0f;
  if (loadValues.size() > 0)
    imageName = loadValues[0];
  if (loadValues.size() > 1)
    scaling = (GLenum)MultiType(loadValues[2]).getFloat();

  return ResourceOBJ(imageName, scaling);
}



Resources::tType<ResourceOBJ> ResourceOBJ::type("OBJ");





ResourceOBJ::OBJResourcePointer::OBJResourcePointer(const std::string& loadString, const Resources::KeepLevel& keepLevel, const StaticModelData::Pointer& data)
    : Resources::StorePointer(loadString, keepLevel) , pointer(data)
{}


